@@ -6,8 +6,8 @@ from pyramid.settings import asbool
 from pyramid.renderers import render_to_response
 
 from ..constants import Conf
+from ..ppss_auth_utils import checkPassword,_,__
 from ..models import PPSsuser,PPSsgroup,PPSspermission,constants
-from ..ppss_auth_utils import checkPassword
 
 from pyramid.view import view_config,forbidden_view_config
 from pyramid.httpexceptions import HTTPFound, HTTPNotFound
@@ -161,7 +161,7 @@ class AuthController():
                     if u:
                         res = u[0]
                     else:
-                        self.retdict["msg"] = 'something went wrong with your login. Please check your informations'
+                        self.retdict["msg"] = __('something went wrong with your login. Please check your informations')
                         return self.retdict
             if res is None:
                 res = PPSsuser.checkLogin(username,password,r.dbsession)
@@ -188,8 +188,11 @@ class AuthController():
                     return HTTPFound(r.route_url("ppss:user:changepassword"))
                 return HTTPFound(postloginpage,headers=headers)
             self.request.dbsession.query(PPSsuser).filter()
-            l.warn("Login attempt failed for user {user}".format(user=username))    
-            self.retdict.update({'logintpl': Conf.publictemplateinherit ,'msg':'something went wrong with your login. Please check your informations'})
+            l.warn("Login attempt failed for user {user}".format(user=username))
+            msgorig = _('something went wrong with your login. Please check your informations')
+            msg = r.localizer.translate(msgorig,domain="ppss_auth")
+            l.info("message is {} with locale '{}' and domain {}".format(msg,r.localizer.locale_name,msgorig.domain))
+            self.retdict.update({'logintpl': Conf.publictemplateinherit ,'msg':msg})
             return self.retdict
         self.retdict.update({'logintpl': Conf.publictemplateinherit , 'msg':''})
         return self.retdict
@@ -220,16 +223,18 @@ class AuthController():
             password = self.request.params.get("password","")
             confirmnewpassword = self.request.params.get("confirmnewpassword","")
             if not username:
-                retdict["msg"] +="Username can not be empty."
+                retdict["msg"] +=__(self.request,"Username can not be empty.")
                 cancreate = False
             if not password:
-                retdict["msg"] +="Password can not be empty."
+                retdict["msg"] +=__(self.request,"Password can not be empty.")
                 cancreate = False
             if password != confirmnewpassword:
-                retdict["msg"] +="Password check doesn't match the password."
+                retdict["msg"] +=__(self.request,"Password check doesn't match the password.")
                 cancreate = False
-            if not checkPassword(PPSsuser(),password):
-                retdict["msg"] +="Password doesn't respect minimum constraints."
+            chkres = checkPassword(PPSsuser(),password)
+            if not chkres:
+                retdict["msg"] += chkres.getMsg(self.request)
+                #__(self.request,"Password doesn't respect minimum constraints.")
                 cancreate = False
             if cancreate:
                 user = PPSsuser(username = username)
@@ -239,7 +244,7 @@ class AuthController():
                     if group:
                         user.groups.append(group)
                 self.request.dbsession.add(user)
-                retdict['msg'] = "User created, please go to login page."
+                retdict['msg'] = __(self.request,"User created, please go to login page.")
                 retdict["link"] = ["login",self.request.route_url("ppsslogin")]
             
             HTTPFound(self.request.route_url("ppsslogin"))
@@ -259,14 +264,31 @@ class AuthController():
         if self.request.POST:
             oldpassword = self.request.params.get("oldpassword")
             newpassword = self.request.params.get("newpassword")
+            confirmnewpassword = self.request.params.get("confirmnewpassword","")
+            if newpassword!=confirmnewpassword:
+                retdict['res']=False
+                retdict['msg']=__(self.request,"Password check doesn't match the password.")
+                return retdict
             username = self.request.session.get(Conf.sessionuser).get("name")
-            res = PPSsuser.checkLogin(username,oldpassword,self.request.dbsession)     
-            if res:
-                res.password = newpassword       
+            user = PPSsuser.checkLogin(username,oldpassword,self.request.dbsession)     
+
+            if user:
+                res = checkPassword(user,newpassword)
+                l.info("checkPassword result for user {} = {}".format(user.username, res.getMsg(self.request) ))
+                if res:
+                    user.setPassword(newpassword)
+                    retdict['msg'] = __(self.request,"Password updated.")
+                else:
+                    retdict['res']=False
+                    retdict['msg'] = res.getMsg(self.request)
+                    #__(self.request,"New password doesn't match constraints." )
+
+                l.info("password upadated for user '{}'".format(res.username))
+                
                 #TODO: execute fake login with post login redirect?
             else:
                 retdict['res']=False
-                retdict['msg']='Old password is wrong'
+                retdict['msg']=__('Old password is wrong')
         return retdict
         
     def listUser(self):
@@ -304,7 +326,7 @@ class AuthController():
 
         if not user:
             retdict['res'] = False
-            retdict['msg'] = "user not found"
+            retdict['msg'] = __("User not found")
 
         editablegroups = []
 
@@ -328,7 +350,7 @@ class AuthController():
                 l.debug("this is a post for creation")
                 username = self.request.params.get("username",None)
                 if not username:
-                    retdict['msg'] = "Username can not be empty."
+                    retdict['msg'] = __("Username can not be empty.")
                     return retdict
                 if len(PPSsuser.byField("username",username,self.request.dbsession))>0:
                     retdict['msg'] = "Username '{}' already used.".format(username)
@@ -352,21 +374,25 @@ class AuthController():
                 #if (self.request.loggeduser.isSuperUser() == False) or selfediting:
                 if requireoldpassowrd:
                     if userid>=0 and (not PPSsuser.checkLogin(username,currentpassword,self.request.dbsession)): 
-                        retdict['msg'] = "{}urrent password does not match!".format("Your c" if selfediting else "C")
+                        if selfediting:
+                            retdict['msg'] = __(self.request,"Your current password does not match!")
+                        else:
+                            retdict['msg'] = __(self.request,"Current password does not match!")
                         return retdict
                         
                 if newpassword==confirmnewpassword:
                     l.info("*****changing password for {}".format(user.username) )
                     res = checkPassword(user,newpassword)
-                    l.info("checkPassword result for user {} = {}".format(user.username, res ))
+                    l.info("checkPassword result for user {} = {}({})".format(user.username, bool(res),res.getMsg(self.request) ))
                     if res:
                         user.setPassword(newpassword)
-                        retdict['msg'] = "password updated."
+                        retdict['msg'] = __(self.request,"Password updated.")
                         canenable = True
                     else:
-                        retdict['msg'] = "new password doesn't match constraints." 
+                        retdict['msg'] = res.getMsg(self.request)
+                        #__(self.request,"New password doesn't match constraints." )
                 else:
-                    retdict['msg'] = "new password doesn't match confirmation field." 
+                    retdict['msg'] = __(self.request,"New password doesn't match confirmation field.")
             user.enabled = 1 if self.request.params.get("enabled")=="1" and canenable else 0
             
             groups=map(int,self.request.params.getall("allgroups"))
@@ -376,24 +402,8 @@ class AuthController():
             self.request.dbsession.flush()
             #return HTTPFound(self.request.route_url('ppss:user:edit',elementid = user.id) )
             #return retdict
-
         return retdict
 
-    # def checkPassword(self):
-    #     newpassword = self.request.get("newpassword","")
-    #     if self.request.session[Conf.sessionuser]['id'] != self.userid and not self.request.session['admin']: 
-    #         return {"res":False,"message":"Utente non autorizzato"}
-    #         #TODO: log the incident
-    #     if not self.user:
-    #         return {"res":False,"message":"Utente non trovato"}
-        
-    #     res = checkPassword(self.user,newpassword)
-    #     if res: 
-    #         return {"res":res,"message":"ok"}
-    #     else:
-    #         return {"res":res,"message":Conf.passwordwrongmessage}
-
-
     def listGroup(self):
         elements = self.request.dbsession.query(PPSsgroup).all()
         return dict(self.retdict,**{'elements':elements}) 
@@ -446,9 +456,9 @@ class AuthController():
             elif perm.permtype!=1:
                 perm.name = name
             else:
-                res = {'res':False,'msg':"Impossibile modificare il permesso"}
+                res = {'res':False,'msg':__("Can't modify this permission")}
                 return dict(self.retdict,dict(res,**{'elements':elements}) )
-            res = {'res':True,'msg':"Permesso modificato"}
+            res = {'res':True,'msg':__("Permission modified")}
             return dict(self.retdict,**dict(res,**{'elements':elements}) )
         elif perm:
             return render_to_response(  Conf.editpermtemplate,dict(self.retdict,**{'perm':perm}),self.request )
@@ -459,9 +469,9 @@ class AuthController():
 
         if perm and perm.permtype != 1:
             self.request.dbsession.delete(perm)
-            res = {'res':True,'msg':"permesso cancellato"}
+            res = {'res':True,'msg':__("Permission deleted.")}
         else:
-            res = {'res':False,'msg':"Impossibile cancellare il permesso"}
+            res = {'res':False,'msg':__("Can't delete this permission")}
         elements = self.request.dbsession.query(PPSspermission).all()
         return dict(self.retdict,**dict(res,**{'elements':elements}) ) 
 
@@ -471,10 +481,10 @@ class AuthController():
         perm = PPSspermission.byId(int(self.request.matchdict.get('targetid',-1)),self.request.dbsession)
         group = PPSsgroup.byId(int(self.request.matchdict.get('elementid',-1)),self.request.dbsession)
         if not perm or not group:
-            return {'res':False,"msg":"error in ids"}
+            return {'res':False,"msg":__("error in ids")}
         for i in group.permissions:
             if i.id == perm.id:
-                return {'res':False,"msg":"already present"}
+                return {'res':False,"msg":__("already present")}
         group.permissions.append(perm)
         l.info(u"adding {perm} to {group}".format(perm=perm,group=group))
         return {'res':True,"msg":"change_perm", "groupperm":group.permdict()}
@@ -494,7 +504,7 @@ class AuthController():
                     l.info("no match")
 
 
-        return {'res':False,'msg':"Impossibile rimuovere il permesso"}
+        return {'res':False,'msg':__("Can't remove this permission")}
 
 
     def addUser2Group(self):
@@ -504,7 +514,7 @@ class AuthController():
             return {'res':False,"msg":"error in ids"}
         for i in group.users:
             if i.id == user.id:
-                return {'res':False,"msg":"already present"}
+                return {'res':False,"msg":__("already present")}
         group.users.append(user)
         l.info(u"adding {user} to {group}".format(user=user,group=group))
         return {'res':True,"msg":"change_user", "elements":group.userdict()}
@@ -517,8 +527,8 @@ class AuthController():
             for i,p in enumerate(group.users):
                 if p.id == user.id:
                     group.users.pop(i)
-                    return {'res':True,"msg":"change_user", "elements":group.userdict()}
-        return {'res':False,'msg':"Impossibile rimuovere il permesso"}
+                    return {'res':True,"msg":__("change_user"), "elements":group.userdict()}
+        return {'res':False,'msg':__("Can't remove this permission")}
 
     def parseqstring(self,qparam):
         if qparam == "" or qparam is None:
